import {useEffect, useState} from 'react';
import './home.css';
import {
    Button, Dialog, DialogTrigger, makeStyles, mergeClasses, MenuItem, MenuList, tokens, Tooltip,
} from "@fluentui/react-components";
import {
    CloudAddFilled, DismissRegular
} from "@fluentui/react-icons";
import {Dial} from "../../api";
import {useToast} from "../../message";
import {Connection} from "../../interfaces/connection";
import {ConnectionCreate} from "../connection/new";
import {useStoreConnection} from "../../store/connection";
import {useStoreBucket} from "../../store/bucket";

const useMenuListContainerStyles = makeStyles({
    container: {
        backgroundColor: tokens.colorNeutralBackground1,
        flex: 1,
        width: "100%",
        paddingTop: "4px",
        paddingBottom: "4px",
    },
    item: {
        display: 'flex',
        height: '100%',
        alignItems: 'center',
        flexDirection: 'row',
        fontSize: '15px',
        '& span': {
            display: 'flex',
            flexDirection: 'row',
            alignItems: 'center',
        },
        '&.active': {
            color: tokens.colorNeutralForeground2BrandHover,
        }
    },
    item_icon: {
        height: '100%',
        display: 'flex',
        justifyContent: 'center',
        alignItems: 'center',
        marginLeft: 'auto',
        border: 'none',
        background: 'transparent',
        "&:hover": {
            color: tokens.colorNeutralForeground2BrandHover,
        }
    }
});


export function Home() {
    const styles = useMenuListContainerStyles();
    const {dispatchMessage} = useToast();
    const [openCreate, setOpenCreate] = useState(false);
    const [conn_filter, set_conn_filter] = useState<string>('');
    const {conn_list, conn_get, conn_update} = useStoreConnection();
    const {bucket_list, bucket_get} = useStoreBucket()

    useEffect(() => {
        conn_get()
    }, []);

    async function handleConnect(item: Connection) {
        let res = await Dial('/api/connection/connect', {id: item.id});
        if (res.status !== 200) {
            dispatchMessage(res.msg, "error")
            return
        }

        conn_update({...item, active: true})
        bucket_get(item, true)
    }

    async function handleDisconnect(item: Connection) {
        let res = await Dial('/api/connection/disconnect', {id: item.id})
        if (res.status !== 200) {
            dispatchMessage(res.msg, "error")
            return
        }
        conn_update({...item, active: false})
    }

    return (
        <div className="container">
            <div className="header">
                <Dialog
                    open={openCreate}
                    onOpenChange={(event, data) => setOpenCreate(data.open)}>
                    <DialogTrigger disableButtonEnhancement>
                        <Button appearance="primary" icon={<CloudAddFilled/>}>
                            新建连接
                        </Button>
                    </DialogTrigger>
                    <ConnectionCreate openFn={setOpenCreate}/>
                </Dialog>
            </div>
            <div className="body">
                <div className="body-connections">
                    <div className="body-connections-search">
                        <input className="body-connections-search-input" type={"text"} placeholder="搜索连接"
                               value={conn_filter}
                               onChange={(e) => set_conn_filter(e.target.value)}/>
                        <div className="body-connections-search-dismiss" onClick={() => {
                            set_conn_filter('')
                        }}>
                            <DismissRegular/>
                        </div>
                    </div>
                    <div className="body-connections-list">
                        <div className={styles.container}>
                            <MenuList>
                                {conn_list.filter(item => item.name.includes(conn_filter)).map(item => {
                                    return <MenuItem
                                        onDoubleClick={async () => {
                                            await handleConnect(item)
                                        }}
                                        className={item.active ? mergeClasses(styles.item, 'active') : styles.item}
                                        key={item.id}>
                                        {item.name}
                                        <Tooltip content="断开连接" relationship="label">
                                            <Button onClick={async () => {
                                                await handleDisconnect(item)
                                            }} size="small" className={styles.item_icon} icon={<DismissRegular/>}/>
                                        </Tooltip>
                                    </MenuItem>
                                })}
                            </MenuList>
                        </div>
                    </div>
                </div>
                <div className="body-content" style={{width:'100%'}}>
                    <div></div>
                    <div style={{width:'100%'}}>
                        <MenuList style={{width:'100%'}}>
                            {bucket_list.map(((item, idx) => {
                                return <MenuItem style={{width:'100%'}} key={idx}>{item.name}</MenuItem>
                            }))}
                        </MenuList>
                    </div>
                </div>
            </div>
            <div className="footer"></div>
        </div>
    )
}